# FIS Membershipt Function R Script v.2

# Last updated: 10/4/2013
# Created by: Sara Bangen (sara.bangen@gmail.com)

# This script was written for users who have a basic working knowledge
# of R.  Note this script will not work with a *.fis file as they are
# normally formatted.  The user will need to create a *.csv using the 
# format found in the exFIS.csv associated with this *R file.


# Outputs: *.pdf of an FIS input and output membership function plot.
#
# Args:
#   data.in:     Filepath to formatted fis *.csv file.
#   plot.title:  Title of the plot.  Needs to have " around text (e.g. "TOTAL STATION FIS INPUTS & OUTPUT")
#   plot.width:  Plot width in inches.
#   plot.height: Plot height in inches.
#   plot.out:    Output *.pdf filepath.

# User defined arguments

data.in     = read.csv("C:\\etal\\Private\\sara.bangen\\Scripts\\R\\FIS_Plot\\exFIS.csv", header=T)
plot.title  = "TOTAL STATION FIS INPUTS & OUTPUT"
plot.width  = c (6)
plot.height = c (9)
plot.out    = "C:\\etal\\Private\\sara.bangen\\Scripts\\R\\FIS_Plot\\exFISPlot.pdf"

# Check if ggplot2 package is installed
# If no, install the package
if (!'ggplot2' %in% installed.packages()) install.packages('ggplot2')


# FIS Plot Function  
fisPlot = function(data.in, plot.title, plot.width, plot.height, plot.out){
    
  # Call on required ggplot2 package
  require(ggplot2)

  # Create FIS membership funciton input and output plot and assign to object 'plot'
  # Plot x ~ y 
  plot = ggplot(data.in, aes(x, y, group = 1)) +
    
  # Plot data as a line, grouping by 'mf' and color lines by 'mf'
  # Use grey scale for different 'mf' levels  
  geom_line(aes(group = mf, color = mf), size = 0.5) +
  #scale_colour_grey(start = 0, end = 0.7) + 
  scale_colour_brewer(palette="RdYlBu") + 
  
  # Create separate plots based on 'input' level
  # Plot in a single column
  # Allow x-axis scales to vary
  facet_wrap(~ input, ncol = 1, scales = "free_x") + 
  
  # Set theme to black and white.  Other option is theme_grey()
  theme_bw() +
  
  # Define y axis labels, plot title, label font size and color
  ylab("Fuzzy Membership") + 
  ggtitle(plot.title) +
  theme(plot.title = element_text(lineheight=.8, face="bold")) +
  theme(axis.title.y = element_text(size=12), axis.text.y = element_text(colour = "#404040",size=10)) +
  theme(axis.title.x = element_blank(), axis.text.x = element_text(colour = "#404040", size=10)) +
  
  # Remove grey box from facet headers
  theme(strip.background = element_blank())
  
  # Output plot to *.pdf
  pdf(plot.out, paper="special", width=plot.width, height=plot.height, useDingbats=FALSE)
  print(plot)
  dev.off()
}

fisPlot(data.in, plot.title, plot.width, plot.height, plot.out)




        
        